..
    This file is part of hepcrawl.
    Copyright (C) 2016, 2017 CERN.

    hepcrawl is a free software; you can redistribute it and/or modify it
    under the terms of the Revised BSD License; see LICENSE file for
    more details.


.. include:: ../INSTALL.rst
